GpuSolverProductionMaxSatSearchStatus

Enum GpuSolverProductionMaxSatSearchStatus 

pub enum GpuSolverProductionMaxSatSearchStatus {
    Satisfiable,
    Unsatisfiable,
}
Expected GPU-CDCL status for a bounded MaxSAT search candidate.

Variants



Satisfiable

The candidate should be satisfiable and eligible for optimum scoring.



Unsatisfiable

The candidate should be unsatisfiable and pruned by GPU CDCL.